==> spip_4.2.9+dfsg.orig.tar.xz: ecrire/lang/public_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'پذيرش ',
	'article' => 'مقاله',
	'articles' => 'مقاله‌ها',
	'articles_auteur' => 'مقاله‌هاى اين نويسنده',
	'articles_populaires' => 'محبوب‌‌ ترين مقاله‌ها',
	'articles_rubrique' => 'مقاله‌هاى اين بخش',
	'aucun_article' => 'مقاله‌اى با اين نشانى وجود ندارد',
	'aucun_auteur' => ' نويسنده‌اى با اين نشانى وجود ندارد',
	'aucun_site' => 'سايتى با اين نشانى وجود ندارد',
	'aucune_breve' => 'خبری با اين نشانى وجود ندارد',
	'aucune_rubrique' => 'بخشى با اين نشانى وجود ندارد',
	'auteur' => 'نويسنده',
	'autres' => 'نويسندگان',
	'autres_breves' => 'خبرهای ديگر',
	'autres_groupes_mots_clefs' => 'گروه‌هاى ديگر واژه كليدها',
	'autres_sites' => ' سايت‌هاى ديگر',

	// B
	'bonjour' => 'سلام',

	// C
	'commenter_site' => 'اظهار نظر در مورد اين سايت',
	'contact' => 'تماس',
	'copie_document_impossible' => 'روبرداری از اين سند ناممكن است',

	// D
	'date' => 'تاريخ',
	'dernier_ajout' => 'آخرين افزوده',
	'dernieres_breves' => 'آخرين خبرها',
	'derniers_articles' => 'آخرين مقاله‌ها',
	'derniers_commentaires' => 'آخرين نظرها',
	'derniers_messages_forum' => 'آخرين پيامهاى منتشر شده در سخنگاه‌ها',

	// E
	'edition_mode_texte' => 'ويرايش با شيوه‌ ی متن',
	'en_reponse' => 'در پاسخ به:',
	'en_resume' => 'خلاصه',
	'envoyer_message' => 'فرستادن پيام',
	'espace_prive' => 'قسمت شخصى',

	// F
	'formats_acceptes' => 'فرمت‌های مورد قبول:@formats@. ',

	// H
	'hierarchie_site' => 'سلسله مراتب سايت',

	// J
	'jours' => 'روزها',

	// L
	'lien_connecter' => 'اتصال',

	// M
	'meme_auteur' => 'از همين نويسنده',
	'meme_rubrique' => 'در همان بخش',
	'memes_auteurs' => 'از همين نويسندگان',
	'message' => 'پيام',
	'messages_forum' => 'پيام‌ها',
	'messages_recents' => 'تازه ترين پيامهاى سخنگاه',
	'mots_clef' => 'كليدواژه',
	'mots_clefs' => 'واژه كليدها',
	'mots_clefs_meme_groupe' => 'واژه كليدهاى يك گروه',

	// N
	'navigation' => 'شبكه نوردى',
	'nom' => 'نام',
	'nouveautes' => 'تازه‌ها',
	'nouveautes_web' => 'تازه‌هاى وب',
	'nouveaux_articles' => 'مقاله‌هاى تازه',
	'nouvelles_breves' => 'خبرهاى تازه',

	// P
	'page_precedente' => 'صفحه ى پيشين',
	'page_suivante' => 'صفحه‌ى بعدى',
	'par_auteur' => 'بوسيله‌ى',
	'participer_site' => 'مي‌توانيد با ثبت نام در اين سايت و ارايه‌ مقاله‌هايتان در فعاليت‌های اين سايت شركت كنيد. به محض ثبت نام، كد ورود به قسمت شخصی سايت با ايميل برای شما ارسال می شود.',
	'plan_site' => 'نقشه‌ى سايت',
	'popularite' => 'محبوبيت سايت',
	'poster_message' => 'يك پيام بفرستيد',
	'proposer_site' => 'مي‌توانيد در اين بخش يك سايت پيشنهاد كنيد:',

	// R
	'repondre_article' => 'پاسخ به اين مقاله',
	'repondre_breve' => 'پاسخ به اين خبر',
	'resultats_recherche' => 'نتيجه‌ى جستجو',
	'retour_debut_forums' => 'بازگشت به ابتداى سخنگاه‌ها',
	'rubrique' => 'بخش',
	'rubriques' => 'بخش‌ها',

	// S
	'signatures_petition' => 'امضاها',
	'site_realise_avec_spip' => 'سايت با اسپيپ درست شده است',
	'sites_web' => 'وب سايت‌ها',
	'sous_rubriques' => 'زيربخش‌ها',
	'spam' => 'اسپم',
	'suite' => 'دنباله',
	'sur_web' => 'در تارنما',
	'syndiquer_rubrique' => 'مشترک سازی اين بخش',
	'syndiquer_site' => 'مشترک سازی تمام سايت',

	// T
	'texte_lettre_information' => 'نامه‌ى اطلاع رسانى سايت',
	'texte_lettre_information_2' => 'نامه سرشمارى تازه‌هاي منتشر شده از :',

	// V
	'ver_imprimer' => 'نسخه‌ى چاپى',
	'voir_en_ligne' => 'آنلاين بنگريد',
	'voir_squelette' => 'اسكلت اين صفحه را ببينيد'
);

==> spip_4.4.7+dfsg.orig.tar.xz: ecrire/lang/public_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'پذيرش ',
	'article' => 'مقاله',
	'articles' => 'مقاله‌ها',
	'articles_auteur' => 'مقاله‌هاى اين نويسنده',
	'articles_populaires' => 'محبوب‌‌ ترين مقاله‌ها',
	'articles_rubrique' => 'مقاله‌هاى اين بخش',
	'aucun_article' => 'مقاله‌اى با اين نشانى وجود ندارد',
	'aucun_auteur' => ' نويسنده‌اى با اين نشانى وجود ندارد',
	'aucun_site' => 'سايتى با اين نشانى وجود ندارد',
	'aucune_breve' => 'خبری با اين نشانى وجود ندارد',
	'aucune_rubrique' => 'بخشى با اين نشانى وجود ندارد',
	'auteur' => 'نويسنده',
	'autres' => 'نويسندگان',
	'autres_breves' => 'خبرهای ديگر',
	'autres_groupes_mots_clefs' => 'گروه‌هاى ديگر واژه كليدها',
	'autres_sites' => ' سايت‌هاى ديگر',

	// B
	'bonjour' => 'سلام',

	// C
	'commenter_site' => 'اظهار نظر در مورد اين سايت',
	'contact' => 'تماس',
	'copie_document_impossible' => 'روبرداری از اين سند ناممكن است',

	// D
	'date' => 'تاريخ',
	'dernier_ajout' => 'آخرين افزوده',
	'dernieres_breves' => 'آخرين خبرها',
	'derniers_articles' => 'آخرين مقاله‌ها',
	'derniers_commentaires' => 'آخرين نظرها',
	'derniers_messages_forum' => 'آخرين پيامهاى منتشر شده در سخنگاه‌ها',

	// E
	'edition_mode_texte' => 'ويرايش با شيوه‌ ی متن',
	'en_reponse' => 'در پاسخ به:',
	'en_resume' => 'خلاصه',
	'envoyer_message' => 'فرستادن پيام',
	'espace_prive' => 'قسمت شخصى',

	// F
	'formats_acceptes' => 'فرمت‌های مورد قبول:@formats@. ',

	// H
	'hierarchie_site' => 'سلسله مراتب سايت',

	// J
	'jours' => 'روزها',

	// L
	'lien_connecter' => 'اتصال',

	// M
	'meme_auteur' => 'از همين نويسنده',
	'meme_rubrique' => 'در همان بخش',
	'memes_auteurs' => 'از همين نويسندگان',
	'message' => 'پيام',
	'messages_forum' => 'پيام‌ها',
	'messages_recents' => 'تازه ترين پيامهاى سخنگاه',
	'mots_clef' => 'كليدواژه',
	'mots_clefs' => 'واژه كليدها',
	'mots_clefs_meme_groupe' => 'واژه كليدهاى يك گروه',

	// N
	'navigation' => 'شبكه نوردى',
	'nom' => 'نام',
	'nouveautes' => 'تازه‌ها',
	'nouveautes_web' => 'تازه‌هاى وب',
	'nouveaux_articles' => 'مقاله‌هاى تازه',
	'nouvelles_breves' => 'خبرهاى تازه',

	// P
	'page_precedente' => 'صفحه ى پيشين',
	'page_suivante' => 'صفحه‌ى بعدى',
	'par_auteur' => 'بوسيله‌ى',
	'participer_site' => 'مي‌توانيد با ثبت نام در اين سايت و ارايه‌ مقاله‌هايتان در فعاليت‌های اين سايت شركت كنيد. به محض ثبت نام، كد ورود به قسمت شخصی سايت با ايميل برای شما ارسال می شود.',
	'plan_site' => 'نقشه‌ى سايت',
	'popularite' => 'محبوبيت سايت',
	'poster_message' => 'يك پيام بفرستيد',
	'proposer_site' => 'مي‌توانيد در اين بخش يك سايت پيشنهاد كنيد:',

	// R
	'repondre_article' => 'پاسخ به اين مقاله',
	'repondre_breve' => 'پاسخ به اين خبر',
	'resultats_recherche' => 'نتيجه‌ى جستجو',
	'retour_debut_forums' => 'بازگشت به ابتداى سخنگاه‌ها',
	'rubrique' => 'بخش',
	'rubriques' => 'بخش‌ها',

	// S
	'signatures_petition' => 'امضاها',
	'site_realise_avec_spip' => 'سايت با اسپيپ درست شده است',
	'sites_web' => 'وب سايت‌ها',
	'sous_rubriques' => 'زيربخش‌ها',
	'spam' => 'اسپم',
	'suite' => 'دنباله',
	'sur_web' => 'در تارنما',
	'syndiquer_rubrique' => 'مشترک سازی اين بخش',
	'syndiquer_site' => 'مشترک سازی تمام سايت',

	// T
	'texte_lettre_information' => 'نامه‌ى اطلاع رسانى سايت',
	'texte_lettre_information_2' => 'نامه سرشمارى تازه‌هاي منتشر شده از :',

	// V
	'ver_imprimer' => 'نسخه‌ى چاپى',
	'voir_en_ligne' => 'آنلاين بنگريد',
	'voir_squelette' => 'اسكلت اين صفحه را ببينيد',
];
